##### Script-R, Main outputs,  Lpez & Corts (2019)

setwd("~/Documentos/Estructura poblacional")
## Population Stratification using TESS3 following https://bcm-uga.github.io/TESS3_encho_sen/articles/main-vignette.html 

library(devtools)
# install_github("cayek/TESS3_encho_sen")
library(LEA)
library(tess3r)

##### Figure 1-F  Population estructure map
genotipo <- read.lfmm("Data.lfmm")
dim(genotipo)
coordenadas_2 <- read_table2("coordenadas_2.csv")
B<-data.matrix(coordenadas_2$V1)
C<-data.matrix(coordenadas_2$V2)
D<-cbind(B,C)

tess3.obj <- tess3(X = genotipo, coord = D, K = 1:10, method = "projected.ls", ploidy = 2, openMP.core.num = 4,max.iteration = 9999999 ) 

q.matrix <- qmatrix(tess3.obj, K = 6)

tiff("Figure1F.tiff",width = 1000,height = 1000)
my.colors <- c("royalblue3","darkorange" ,"darkred" ,"violetred1","springgreen4","purple")
my.palette <- CreatePalette(my.colors, 4)
map.polygon <- getMap(resolution = "high")
pl <- ggtess3Q(q.matrix, D,
               col.palette = my.palette,interpolation.model = FieldsKrigModel(1000))
pl +
  geom_path(data = map.polygon, aes(x = long, y = lat, group = group)) +
  xlim(-120, -60) + 
  ylim(-30, 25) + 
  coord_equal() + 
  geom_point(data = as.data.frame(D), aes(x = V1, y = V2), shape =20, colour="black" ,size =3, show.legend=TRUE) + 
  xlab("Longitute") +
  ylab("Latitude") + 
  theme_bw() + theme(text = element_text(size=20), title = element_text(size=20, face='bold'))
dev.off()


##### Figure 1-A  Population estructure map
tiff("Figure1A.tiff",width = 625,height = 656)
par(mfrow=c(3,1),new=TRUE)
###matriz 2
q.matrix_2 <- read.table("q.matrix_2.txt")

B2<-data.matrix(q.matrix_2$V1)
C2<-data.matrix(q.matrix_2$V2)
P<-cbind(B2,C2)
P<-as.qmatrix(P)

my.colors <- c("royalblue3", "darkred")
my.palette <- CreatePalette(my.colors, 4)
# par(new=TRUE, fig=c(0.1,0.9,0.25,0.55))
barplot(P, border ="NA", space = 0,las=1,sort.by.Q = FALSE, 
        main = "K2", cex.axis=2, cex.lab =2, cex.main=2,
        #xlab = "Individuals", ylab = "Ancestry proportions", 
        col.palette = my.palette) 


###matriz 5
q.matrix_5 <- read.table("q.matrix_5.txt")

Y<-data.matrix(q.matrix_5$V1)
U<-data.matrix(q.matrix_5$V2)
I<-data.matrix(q.matrix_5$V3)
O<-data.matrix(q.matrix_5$V4)
P<-data.matrix(q.matrix_5$V5)
T<-cbind(Y,U,I,O,P)
T<-as.qmatrix(T)

my.colors <- c("royalblue3", "darkred", "springgreen4", "purple","darkorange")
my.palette <- CreatePalette(my.colors, 4)
# par(new=TRUE, fig=c(0.1,0.9,0.42,0.72))
barplot(T, border = "NA", space = 0,las=1,sort.by.Q = FALSE,
        main = "K5", cex.axis=2,cex.lab =2, cex.main=2,
        #xlab = "Individuals", 
        ylab = "Ancestry proportions", 
        col.palette = my.palette) 


###matriz 6
q.matrix_6<- read.table("q.matrix_6.txt")

A<-data.matrix(q.matrix_6$V1)
B<-data.matrix(q.matrix_6$V2)
C<-data.matrix(q.matrix_6$V3)
D<-data.matrix(q.matrix_6$V4)
E<-data.matrix(q.matrix_6$V5)
H<-data.matrix(q.matrix_6$V6)
F<-cbind(A,B,C,D,E,H)
F<-as.qmatrix(F)

my.colors <- c("springgreen4", "royalblue3", "purple", "darkorange","darkred","violetred1")
my.palette <- CreatePalette(my.colors, 4)
# par(new=TRUE, fig=c(0.1,0.9,0.59,0.89))
barplot(F, border = "NA", space = 0,las=1, sort.by.Q = FALSE,
        main = "K6", cex.main=2,
        #xlab = "Individuals", ylab = "Ancestry proportions", 
        col.palette = my.palette, cex.axis=2,cex.lab =2) -> bp
#axis(1, at = 1:nrow(F), labels = bp$order, las = 3, cex.axis = .4) 
bp + theme(axis.title.y = element_text(colour="grey20",size=40,angle=90,hjust=.5,vjust=.5,face="plain"))
dev.off()

## Plot Manhattan ALL following qqman R-package
##### Example with HSI index (Figure 2)

library(qqman)

manhattan_SuperGWAS<-function (x, chr = "CHR", bp = "BP", p = "P", snp = "SNP", col = c("gray10", 
                                                                                        "gray60"), chrlabs = NULL, suggestiveline = -log10(0.00009999), 
                               genomewideline = 5.67, highlight = NULL, logp = TRUE, 
                               annotatePval = NULL, annotateTop = TRUE, ...) 
{
  CHR = BP = P = index = NULL
  if (!(chr %in% names(x))) 
    stop(paste("Column", chr, "not found!"))
  if (!(bp %in% names(x))) 
    stop(paste("Column", bp, "not found!"))
  if (!(p %in% names(x))) 
    stop(paste("Column", p, "not found!"))
  if (!(snp %in% names(x))) 
    warning(paste("No SNP column found. OK unless you're trying to highlight."))
  if (!is.numeric(x[[chr]])) 
    stop(paste(chr, "column should be numeric. Do you have 'X', 'Y', 'MT', etc? If so change to numbers and try again."))
  if (!is.numeric(x[[bp]])) 
    stop(paste(bp, "column should be numeric."))
  if (!is.numeric(x[[p]])) 
    stop(paste(p, "column should be numeric."))
  d = data.frame(CHR = x[[chr]], BP = x[[bp]], P = x[[p]])
  if (!is.null(x[[snp]])) 
    d = transform(d, SNP = x[[snp]])
  d <- subset(d, (is.numeric(CHR) & is.numeric(BP) & is.numeric(P)))
  d <- d[order(d$CHR, d$BP), ]
  if (logp) {
    d$logp <- -log10(d$P)
  }
  else {
    d$logp <- d$P
  }
  d$pos = NA
  d$index = NA
  ind = 0
  for (i in unique(d$CHR)) {
    ind = ind + 1
    d[d$CHR == i, ]$index = ind
  }
  nchr = length(unique(d$CHR))
  if (nchr == 1) {
    d$pos = d$BP
    ticks = floor(length(d$pos))/2 + 1
    xlabel = paste("Chromosome", unique(d$CHR), "position")
    labs = ticks
  }
  else {
    lastbase = 0
    ticks = NULL
    for (i in unique(d$index)) {
      if (i == 1) {
        d[d$index == i, ]$pos = d[d$index == i, ]$BP
      }
      else {
        lastbase = lastbase + tail(subset(d, index == 
                                            i - 1)$BP, 1)
        d[d$index == i, ]$pos = d[d$index == i, ]$BP + 
          lastbase
      }
      ticks = c(ticks, (min(d[d$index == i, ]$pos) + max(d[d$index == 
                                                             i, ]$pos))/2 + 1)
    }
    xlabel = "Chromosome"
    labs <- unique(d$CHR)
  }
  xmax = ceiling(max(d$pos) * 1.03)
  xmin = floor(max(d$pos) * -0.03)
  def_args <- list(xaxt = "n", bty = "n", xaxs = "i", yaxs = "i", 
                   las = 1, pch = 19, xlim = c(xmin, xmax), ylim = c(0, 
                                                                     ceiling(max(d$logp))), xlab = xlabel, ylab = expression(-log[10](italic(p))))
  dotargs <- list(...)
  do.call("plot", c(NA, dotargs, def_args[!names(def_args) %in% 
                                            names(dotargs)]))
  if (!is.null(chrlabs)) {
    if (is.character(chrlabs)) {
      if (length(chrlabs) == length(labs)) {
        labs <- chrlabs
      }
      else {
        warning("You're trying to specify chromosome labels but the number of labels != number of chromosomes.")
      }
    }
    else {
      warning("If you're trying to specify chromosome labels, chrlabs must be a character vector")
    }
  }
  if (nchr == 1) {
    axis(1, ...)
  }
  else {
    axis(1, at = ticks, labels = labs, ...)
  }
  col = rep(col, max(d$CHR))
  if (nchr == 1) {
    with(d, points(pos, logp, pch = 19, col = col[1], ...))
  }
  else {
    icol = 1
    for (i in unique(d$index)) {
      with(d[d$index == unique(d$index)[i], ], points(pos, 
                                                      logp, col = col[icol], pch = 19, ...))
      icol = icol + 1
    }
  }
  if (suggestiveline) 
    abline(h = suggestiveline, col = "steelblue",pch="-",cex=1.5,lty=3)
  if (genomewideline) 
    abline(h = genomewideline, col = "indianred4",pch="-",cex=1.5,lty=3)
  if (!is.null(highlight)) {
    if (any(!(highlight %in% d$SNP))) 
      warning("You're trying to highlight SNPs that don't exist in your results.")
    d.highlight = d[which(d$SNP %in% highlight), ]
    with(d.highlight, points(pos, logp, col = "red", pch = 25, 
                             ...))
  }
  if (!is.null(annotatePval)) {
    topHits = subset(d, P <= annotatePval)
    par(xpd = TRUE)
    if (annotateTop == FALSE) {
      with(subset(d, P <= annotatePval), textxy(pos, -log10(P), 
                                                offset = 0.625, labs = topHits$SNP, cex = 0.45), 
           ...)
    }
    else {
      topHits <- topHits[order(topHits$P), ]
      topSNPs <- NULL
      for (i in unique(topHits$CHR)) {
        chrSNPs <- topHits[topHits$CHR == i, ]
        topSNPs <- rbind(topSNPs, chrSNPs[1, ])
      }
      textxy(topSNPs$pos, -log10(topSNPs$P), offset = 0.625, 
             labs = topSNPs$SNP, cex = 0.5, ...)
    }
  }
  par(xpd = FALSE)
}

######### GEA outputs
setwd("~/Documentos/Asociacion_salida gapit")
MLM_HSI <- read_delim("GAPIT.MLM.HSI.GWAS.Results.txt", 
                      "\t", escape_double = FALSE, trim_ws = TRUE)
CMLM_HSI <- read_delim("GAPIT.CMLM.HSI.GWAS.Results.txt", 
                       "\t", escape_double = FALSE, trim_ws = TRUE)
SUPER_HSI <- read_delim("GAPIT..HSI.GWAS.Results.txt", 
                        "\t", escape_double = FALSE, trim_ws = TRUE)
FARMCPU_HSI <- read_delim("FarmCPU.Iteration_01.HSI.GWAS.Results.txt", 
                          "\t", escape_double = FALSE, trim_ws = TRUE)
BLINK_HSI <- read_delim("BLINK.HSI.GWAS.Results.txt", 
                        "\t", na = "NA", escape_double = FALSE, trim_ws = TRUE)

pdf("Figure2.pdf",width=10,height=10,paper="special")
m<-rbind(c(1,1,1,1,2),c(3,3,3,3,4),c(5,5,5,5,6),c(7,7,7,7,8),c(9,9,9,9,10))
layout(m)
par(mar=c(2,1,1,1)+0.05)
par(oma=c(5,5,1,1),xpd=TRUE,mgp=c(4,1.1,0))


###################### MLM
manhattan_SuperGWAS(MLM_HSI,chrlabs=c("","","","","","","","","","",""), highlight = snpsOfInterest, 
                    #main = "A", 
                    cex = 0.2, cex.axis = 1, #genomewideline = -log10(0.0002),
                    col = c("lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey"))
legend(x="topleft",legend="A",bty="n")

qq(MLM_HSI$P, cex=.5,col = "gray8",type = "p",las=1)
abline(h = -log10(0.00009999), col = "steelblue",pch="-",cex=1.5,lty=3)
abline(h = 5.67, col = "indianred4",pch="-",cex=1.5,lty=3)
legend(x="topleft",legend="B",bty="n")

###################### CMLM
manhattan_SuperGWAS(CMLM_HSI,chrlabs=c("","","","","","","","","","",""), highlight = snpsOfInterest, 
                    #main = "B", 
                    cex = 0.2, cex.axis = 1, #genomewideline = -log10(0.0002),
                    col = c("lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey"))
legend(x="topleft",legend="C",bty="n")

qq(CMLM_HSI$P, cex=.5,col = "gray8",type = "p",las=1)
abline(h =-log10(0.00009999), col = "steelblue",pch="-",cex=1.5,lty=3)
abline(h = 5.67, col = "indianred4",pch="-",cex=1.5,lty=3)
legend(x="topleft",legend="D",bty="n")

###################### SUPER
manhattan_SuperGWAS(SUPER_HSI,chrlabs=c("","","","","","","","","","",""), #highlight = snpsOfInterest, 
                    #main = "C", 
                    cex = 0.2, cex.axis = 1, #genomewideline = -log10(0.0002),suggestiveline                
                    col = c("lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey"))
legend(x="topleft",legend="E",bty="n")

qq(SUPER_HSI$P, cex=.5,col = "gray8",type = "p",las=1)
abline(h = -log10(0.00009999), col = "steelblue",pch="-",cex=1.5,lty=3)
abline(h = 5.67, col = "indianred4",pch="-",cex=1.5,lty=3)
legend(x="topleft",legend="F",bty="n")

###################### FARMCPU
manhattan_SuperGWAS(FARMCPU_HSI,chrlabs=c("","","","","","","","","","",""), #highlight = snpsOfInterest, 
                    #main = "D", 
                    cex = 0.2, cex.axis = 1, #genomewideline = -log10(0.0002),
                    col = c("lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey"))
legend(x="topleft",legend="G",bty="n")

qq(FARMCPU_HSI$P, cex=.5,col = "gray8",type = "p",las=1)
abline(h =-log10(0.00009999), col = "steelblue",pch="-",cex=1.5,lty=3)
abline(h = 5.67, col = "indianred4",pch="-",cex=1.5,lty=3)
legend(x="topleft",legend="H",bty="n")

###################### BLINK
manhattan_SuperGWAS(BLINK_HSI,chrlabs=c("Pv01","Pv02","Pv03","Pv04","Pv05","Pv06","Pv07","Pv08","Pv09","Pv10","Pv11"), #highlight = snpsOfInterest, 
                    #main = "E", 
                    cex = 0.2, cex.axis = 1, #genomewideline = -log10(0.0002),
                    col = c("lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey", "black","lightslategrey"))
legend(x="topleft",legend="I",bty="n")

qq(BLINK_HSI$P, cex=.5,col = "gray8",type = "p",las=1)
abline(h = -log10(0.00009999), col = "steelblue",pch="-",cex=1.5,lty=3)
abline(h = 5.67, col = "indianred4",pch="-",cex=1.5,lty=3)
legend(x="topleft",legend="J",bty="n")


mtext("Observed -log(Pvalue)",side=2, outer = TRUE, at = 0.5, line = 3.5 )
mtext("MLM",side=2, outer = TRUE, at = 0.9, line = 1.5, col = "indianred4" )
mtext("CMLM",side=2, outer = TRUE, at = 0.7, line = 1.5, col = "indianred4" )
mtext("SUPER",side=2, outer = TRUE, at = 0.5, line = 1.5, col = "indianred4" )
mtext("FARMCPU",side=2, outer = TRUE, at = 0.3, line = 1.5, col = "indianred4" )
mtext("BLINK",side=2, outer = TRUE, at = 0.1, line = 1.5, col = "indianred4" )
mtext("Expected -log(Pvalue)",side=1, outer = TRUE, at = 0.9, line = 2 )
mtext("Chromosome",side=1, outer = TRUE, at = 0.4, line = 2 )

dev.off
graphics.off()

#Plot physical map following R-script of Corts & Blair (2018)
##### Figure 6

setwd("~/Documentos/Mapa genetico/modelos")
mlm_n <-read_delim("GWAS_SUPER_HIT.Results","\t", escape_double = FALSE, trim_ws = TRUE) 
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

SUPER_HSI<- read_delim("GWAS_SUPER_HSI.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

SUPER_HIT<- read_delim("GWAS_SUPER_HIT.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

SUPER_PCA1<- read_delim("GWAS_SUPER_PCA1.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

FARMCPU_HSI<- read_delim("GWAS_FARMCPU_PC_HSI.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

FARMCPU_HIT<- read_delim("GWAS_FARMCPU_PC_HIT.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

FARMCPU_PCA1<- read_delim("GWAS_FARMCPU_PC_PCA1.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

BLINK_HSI<- read_delim("GWAS_BLINK_PC_HSI.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

BLINK_HIT<- read_delim("GWAS_BLINK_PC_HIT.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

BLINK_PCA1<- read_delim("GWAS_BLINK_PC_PCA1.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

FARMCPU_HSI_Q<- read_delim("GWAS_FARMCPU_Q_HSI.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

FARMCPU_HIT_Q<- read_delim("GWAS_FARMCPU_Q_HIT.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

FARMCPU_PCA1_Q<- read_delim("GWAS_FARMCPU_Q_PCA1.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

BLINK_HSI_Q<- read_delim("GWAS_BLINK_Q_HSI.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

BLINK_HIT_Q<- read_delim("GWAS_BLINK_Q_HIT.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

BLINK_PCA1_Q<- read_delim("GWAS_BLINK_Q_PCA1.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())

Associated<- read_delim("GWAS_associated.Results","\t", escape_double = FALSE, trim_ws = TRUE)
cols(Trait = col_character(),Marker = col_character(),Chr = col_integer(),Pos = col_integer(),p = col_double())


############################
#Chr analysis
mlm_n<-mlm_n[!is.na(mlm_n$Pos),]
mlm_n$Chr<-factor(mlm_n$Chr)

chr_label<-c("Pv01","Pv02","Pv03","Pv04","Pv05","Pv06","Pv07","Pv08","Pv09","Pv10","Pv11")
chr<-data.frame(chr=1:11,len=tapply(mlm_n$Pos,mlm_n$Chr,max))
chr$mid<-chr$len/2
for(i in (1:nrow(chr))){chr[i,"len_cum"]<-sum(chr[1:i,"len"]);chr[i,"mid_cum"]<-(chr[i,"len_cum"]-chr[i,"mid"])}
chr$Chr<-rownames(chr)

mlm_n<-merge(mlm_n,chr[,c(1,6)],by="Chr",all.x = TRUE)

#Significant markers
choose_aa<-function(trait,df,maxs){
  tt<-df[df$Trait==trait,]
  tt$p<-as.numeric(tt$p)
  tt<-tt[order(-(-log10(tt$p))),][1:maxs,]
  tt<-tt[!is.na(tt$Trait),c("Trait","Marker","Chr","Pos","p")]
  return(tt)
}

bc<-(4)
names_ass<-c("HIT_SUPER","HSI_SUPER","PCA1_SUPER","HIT_FARMCPU","HSI_FARMCPU","PCA1_FARMCPU","HIT_BLINK","HSI_BLINK","PCA1_BLINK","HIT_FARMCPU_Q","HSI_FARMCPU_Q","PCA1_FARMCPU_Q","HIT_BLINK_Q","HSI_BLINK_Q","PCA1_BLINK_Q","Associated")
names_ass_fig<-c("HIT (SUPER-PC)","HSI (SUPER-PC)","PCA1 (SUPER-PC)","HIT (FARMCPU-PC)","HSI (FARMCPU-PC)","PCA1 (FARMCPU-PC)","HIT (BLINK-PC)","HSI (BLINK-PC)","PCA1 (BLINK-PC)","HIT (FARMCPU-Tess3)","HSI (FARMCPU-Tess3)","PCA1 (FARMCPU-Tess3)","HIT (BLINK-Tess3)","HSI (BLINK-Tess3)","PCA1 (BLINK-Tess3)","Associated")
ass_new<-rbind(
  choose_aa("HIT_SUPER",SUPER_HIT,12),
  choose_aa("HSI_SUPER",SUPER_HSI,11),
  choose_aa("PCA1_SUPER",SUPER_PCA1,9),
  choose_aa("HIT_FARMCPU",FARMCPU_HIT,11),
  choose_aa("HSI_FARMCPU",FARMCPU_HSI,12),
  choose_aa("PCA1_FARMCPU",FARMCPU_PCA1,27),
  choose_aa("HIT_BLINK",BLINK_HIT,21),
  choose_aa("HSI_BLINK",BLINK_HSI,39),
  choose_aa("PCA1_BLINK",BLINK_PCA1,73),
  choose_aa("HIT_FARMCPU_Q",FARMCPU_HIT_Q,8),
  choose_aa("HSI_FARMCPU_Q",FARMCPU_HSI_Q,10),
  choose_aa("PCA1_FARMCPU_Q",FARMCPU_PCA1_Q,9),
  choose_aa("HIT_BLINK_Q",BLINK_HIT_Q,12),
  choose_aa("HSI_BLINK_Q",BLINK_HSI_Q,5),
  choose_aa("PCA1_BLINK_Q",BLINK_PCA1_Q,11),
  choose_aa("Associated",Associated,24)
)

ass_new<-merge(ass_new,chr[,c(1,6)],by="Chr",all.x = TRUE)
glm_pool_sig<-ass_new
glm_pool_sig$Chr<-glm_pool_sig$chr
for(i in 1:16){
  if(i==1){glm_pool_sig[which(glm_pool_sig$Chr==i),"pos_cum"]<-(glm_pool_sig[which(glm_pool_sig$Chr==i),]$Pos)}
  if(i!=1){glm_pool_sig[which(glm_pool_sig$Chr==i),"pos_cum"]<-(glm_pool_sig[which(glm_pool_sig$Chr==i),]$Pos+chr[chr$chr==i-1,"len_cum"])}
}
write.table(glm_pool_sig,"sig_ass.txt",sep="\t",col.names = TRUE,row.names = FALSE)

glm_pool_sig<-read.table("sig_ass.txt",sep="\t",header=TRUE)
ass_new<-glm_pool_sig
#glm_pool_sig_regions<-read.table("glm_pool_sig_ass_regions.txt",sep="\t",header=TRUE)

#Plot physical map
cex_valu<-0.7
pdf("Figure6.pdf",width=18,height=8,paper="special")
par(mfrow=c(1,1))
par(mar=c(0.2,3,2,3)+0.2)
par(xpd=TRUE)
par(mgp=c(2,0.8,0))
mlm_n$Pos<-as.numeric(mlm_n$Pos)
mlm_n$Chra<-as.numeric(mlm_n$Chr)
mlm_n<-as.data.frame(mlm_n)
plot(Pos/1000000~I(chr-0),mlm_n,main="",axes=FALSE,xlab="",ylab="",xlim=as.roman(c(1,12)),ylim=rev(range(mlm_n$Pos/1000000)),pch="-",cex=cex_valu)
esp<-0.058
for(i in 1:16){
  if(i==1){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="darkorange2",pch=1,cex=cex_valu)
    par(xpd=NA)
  } else if(i==2){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="darkorange2",pch=19,cex=cex_valu)
    
  } else if(i==3){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="darkorange2",pch=4,cex=cex_valu)
  } else if(i==4){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="darkgreen",pch=1,cex=cex_valu)
    
  } else if(i==5){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="darkgreen",pch=19,cex=cex_valu)
  } else if(i==6){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="darkgreen",pch=4,cex=cex_valu)
    
  } else if(i==7){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="royalblue4",pch=1,cex=cex_valu)
  } else if(i==8){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="royalblue4",pch=19,cex=cex_valu)
    
  } else if(i==9){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="royalblue4",pch=4,cex=cex_valu)
  } else if(i==10){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="darkorchid3",pch=2,cex=cex_valu)
    
    # segments(set$Chr,set$Pos/1000000,set$Chr+1,set$Pos/1000000,col="lightyellow3",lty="dashed",cex=0.2)
    # abline(Pos/1000000~I(Chr+0.09*i),set,col="grey",pch="-",cex=cex_valu)
  } else if(i==11){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="darkorchid3",pch=17,cex=cex_valu)
  } else if(i==12){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="darkorchid3",pch=6,cex=cex_valu)
  } else if(i==13){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="deeppink1",pch=2,cex=cex_valu)
  } else if(i==14){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="deeppink1",pch=17,cex=cex_valu)
  } else if(i==15){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="deeppink1",pch=6,cex=cex_valu)
  } else if(i==16){
    set<-glm_pool_sig[glm_pool_sig$Trait==names_ass[i],]
    points(Pos/1000000~I(Chr+esp*i),set,col="red1",pch=8,cex=cex_valu)
    segments(set$Chr,set$Pos/1000000,set$Chr+1,set$Pos/1000000,col="red1",lty="dashed",cex=0.2)
    
  }
  #polygon(c(i-1,i+1,i+1,i-1,i-1),c(0,0,60,60,0), col = rgb(105,255,105,50,max = 255), border = NA)
  
  #points(Pos/1000000~I(Chr+0.1*i),set,col=i,pch="-",cex=cex_valu)
  #text(I(Chr+0.1*i),Pos/1000000,set,srt=270,xpd=TRUE,cex.lab=10,labels=names_ass[i],col="darkgray",font=2)
}

for(i in 1:11){
  if(i==1){
    par(xpd=NA)
    polygon(c(i,i+1,i+1,i,i),c(0,0,60,60,0), col = rgb(105,80,105,22,max = 255), border = NA)
  } else if(i==3){
    polygon(c(i,i+1,i+1,i,i),c(0,0,60,60,0), col = rgb(105,80,105,22,max = 255), border = NA)
  } else if(i==5){
    polygon(c(i,i+1,i+1,i,i),c(0,0,60,60,0), col = rgb(105,80,105,22,max = 255), border = NA)
  } else if(i==7){
    polygon(c(i,i+1,i+1,i,i),c(0,0,60,60,0), col = rgb(105,80,105,22,max = 255), border = NA)
  } else if(i==9){
    polygon(c(i,i+1,i+1,i,i),c(0,0,60,60,0), col = rgb(105,80,105,22,max = 255), border = NA)
  } else if(i==11){
    polygon(c(i,i+1,i+1,i,i),c(0,0,60,60,0), col = rgb(105,80,105,22,max = 255), border = NA)
  } 
}

#########################################
#points(Pos/1000000~I(Chr+0.2),glm_pool_sig_regions,col=Color,pch="-",cex=cex_valu)
#points(mid~I(chr-0.1),centro,col="gray",pch=19)
#for(i in 1:11){segments(i-0.1,centro[centro$chr==i,"end"],i-0.1,centro[centro$chr==i,"start"],col="gray",lty=1)}
# polygon(c(i-1,i+1,i+1,i-1,i-1),c(0,0,60,60,0), col = rgb(105,255,105,50,max = 255), border = NA)
axis(side=3,at=c(1:11)+0.5,labels=chr_label,col="white",cex.axis=0.9,cex.lab=0.5,pos=0.007)
axis(side=2,at=seq(0,60,by=5),las=1,cex.axis=0.8,pos = 0.9,ylab="Mb")
#axis(side=4,at=seq(0,60,by=5),las=1,cex.axis=0.8)
text(0.6,30,"Mb",srt=90,xpd=TRUE,cex.lab=0.8)
legend(x=1,y=56,legend=names_ass_fig[1:3],pch=c(1,19,4),col=c("darkorange2","darkorange2","darkorange2"),bty="n",cex=0.6)
legend(x=2,y=56,legend=names_ass_fig[4:6],pch=c(1,19,4),col=c("darkgreen","darkgreen","darkgreen"),bty="n",cex=0.6)
legend(x=3,y=56,legend=names_ass_fig[7:9],pch=c(1,19,4),col=c("royalblue4","royalblue4","royalblue4"),bty="n",cex=0.6)
legend(x=4,y=56,legend=names_ass_fig[10:12],pch=c(2,17,6),col=c("darkorchid3","darkorchid3","darkorchid3"),bty="n",cex=0.6)
legend(x=5,y=56,legend=names_ass_fig[13:15],pch=c(2,17,6,8),col=c("deeppink1","deeppink1","deeppink1","red1"),bty="n",cex=0.6)
legend(x=6,y=56,legend=names_ass_fig[16],pch=c(8),col=c("red1"),bty="n",cex=0.6)

dev.off
graphics.off()